*! Adapted from Glenn Hoetker's complogit routine.
*! Hoetker's complogitml must also be installed.
*! This version is designed for use in simulation studies
*! where there are two x variables and one dichotomous 
*! grouping variable.  It will usually be used in conjunction
*! with a simxx file.  Full syntax:
*! complogit y x1 x2, g(groupvar) s(x2)

program define complogitx, rclass
	version 8.2
	syntax varlist, Group(varlist min=1 max=1)  ///
	[SPecific(varlist min=1 max=1)]
	capture program drop complogitml
	capture estimates drop all zero one two allison_1 allison_2
	
// Parse variable list
	gettoken dep xvars : varlist
	
// Run logit equations and save results
	
// Group 0
	display as text _newline"{hline 80}
	display as text  "Estimating " "`group'"  "=0"
	display as text "{hline 80}
	logit `dep' `xvars' if `group'==0, score(`zero') nolog
	estimates store zero
	tempname g0beta
	matrix `g0beta' = e(b)

// Group 1
	display as text _newline"{hline 80}
	display as text "Estimating " "`group'"  "=1" 
	display as text "{hline 80}
	logit `dep' `xvars' if `group'==1, score(`one') nolog
	estimates store one
	tempname g1beta
	matrix `g1beta' = e(b)
	
// Both Groups pooled together
	display as text _newline"{hline 80}
	display as text "Residual variation NOT allowed to differ"
	display as text"{hline 80}"
	logit `dep' `xvars' `group', score(`two') nolog
	estimates store two
	tempname g2beta
	matrix `g2beta' = e(b)

// Basic Allison/ hetero logit model - Residual variances differ
// but coefficients are constrained to be the same across groups.
	display as text _newline"{hline 80}
	display as text "Allowing residual variation to differ"
	display as text"{hline 80}"
	ml model lf complogitml (`dep'=`xvars' `group') (delta: `group', nocons)
	ml search
	ml maximize, difficult nolog iterate(100)
	estimates store allison_1 
	tempname gdbeta
	matrix `gdbeta' = e(b)
	
// Estimate if residual variation differs across groups by likelihood ratio
	display as text _newline "{hline 80}
	display as text "Likelihood ratio test to reject" ///
	" null hypothesis of equal residual variation" _newline "{hline 80}"
	lrtest two allison_1, force
	
	// Store test results
	local resid_lr = r(chi2)
	if r(p)!=. local resid_sig = r(p) <= .05

	
// Test if ANY coefficient differs
	display as text _newline "{hline 80}
	display as text "Likelihood ratio test to reject" ///
	" null hypothesis that all coefficients are the same" _newline "{hline 80}"
	lrtest (zero one) allison_1, force
	
	// Store test results
	local coeff_lr = r(chi2)
	if r(p)!=. local coeff_sig = r(p) <= .05

	
// Test of whether specific coefficient differs	
	if "`specific'"~="" {
		capture drop I_`group'_`specific'
		gen I_`group'_`specific'=`group'*`specific'
		ml model lf complogitml (`dep'=`xvars' `group' I_`group'_`specific' ) (delta: `group', nocons)
		ml search
		ml maximize, difficult nolog iterate(100)
		estimates store allison_2
		tempname gsbeta
		matrix `gsbeta' = e(b)
	
		//LR test
		display as text _newline "{hline 80}
		display as text "LR chi-square test to reject" ///
		" null hypothesis that coefficient of" _newline "`specific'" ///
		" is the same across groups" _newline "{hline 80}"
		display as text "Test assumes that all other coefficients are equal!"
		lrtest allison_1 allison_2
	
		// Store test results
		local spec_lr = r(chi2)
		if r(p)!=. local spec_sig = r(p) <= .05
	}

// Return beta values as scalars
	return scalar g0b1 = `g0beta'[1,1]
	return scalar g0b2 = `g0beta'[1,2]
	return scalar g0b0 = `g0beta'[1,3]

	return scalar g1b1 = `g1beta'[1,1]
	return scalar g1b2 = `g1beta'[1,2]
	return scalar g1b0 = `g1beta'[1,3]

	return scalar g2b1 = `g2beta'[1,1]
	return scalar g2b2 = `g2beta'[1,2]
	return scalar g2group = `g2beta'[1,3]
	return scalar g2b0 = `g2beta'[1,4]
	
	return scalar gdb1 = `gdbeta'[1,1]
	return scalar gdb2 = `gdbeta'[1,2]
	return scalar gdgroup = `gdbeta'[1,3]
	return scalar gdb0 = `gdbeta'[1,4]
	return scalar gddelta = `gdbeta'[1,5]
 	
 	if "`specific'"~="" {
 		return scalar gsb1 = `gsbeta'[1,1]
 		return scalar gsb2 = `gsbeta'[1,2]
 		return scalar gsgroup = `gsbeta'[1,3]
 		return scalar gsintr = `gsbeta'[1,4]
 		return scalar gsb0 = `gsbeta'[1,5]
 		return scalar gsdelta = `gsbeta'[1,6]
 	}
  	

//Return test stat values in r

	if "`resid_lr'"!="" {
		return scalar resid_lr = `resid_lr'
		return scalar resid_sig = `resid_sig'
	}
	
	if "`coeff_lr'"!="" {
		return scalar coeff_lr = `coeff_lr'
		return scalar coeff_sig = `coeff_sig'
	}
	
	if "`spec_lr'"!="" {
		return scalar spec_lr = `spec_lr'
		return scalar spec_sig = `spec_sig'
	}
		

end


